@@ -13,7 +13,7 @@ use warnings ;
 use bytes ;
 our ($VERSION, $XS_VERSION, @ISA, @EXPORT, $AUTOLOAD);
 
-$VERSION = '2.036';
+$VERSION = '2.039';
 $XS_VERSION = $VERSION; 
 $VERSION = eval $VERSION;
 
@@ -383,6 +383,19 @@ sub Compress::Raw::Zlib::Deflate::new
 
 }
 
+sub Compress::Raw::Zlib::deflateStream::STORABLE_freeze
+{
+    my $type = ref shift;
+    croak "Cannot freeze $type object\n";
+}
+
+sub Compress::Raw::Zlib::deflateStream::STORABLE_thaw
+{
+    my $type = ref shift;
+    croak "Cannot thaw $type object\n";
+}
+
+
 sub Compress::Raw::Zlib::Inflate::new
 {
     my $pkg = shift ;
@@ -420,6 +433,18 @@ sub Compress::Raw::Zlib::Inflate::new
                  $got->value('Dictionary')) ;
 }
 
+sub Compress::Raw::Zlib::inflateStream::STORABLE_freeze
+{
+    my $type = ref shift;
+    croak "Cannot freeze $type object\n";
+}
+
+sub Compress::Raw::Zlib::inflateStream::STORABLE_thaw
+{
+    my $type = ref shift;
+    croak "Cannot thaw $type object\n";
+}
+
 sub Compress::Raw::Zlib::InflateScan::new
 {
     my $pkg = shift ;
